##########
##Why R?##
##########

#Free and open source
#Flexible
#Excellent Graphics

###################
##Basic Data in R##
###################

##R is a vector programming language
##Below I enter two vectors, x and y
x<-c(1,2,3,4,5) #the c() command is used to group the numbers together as a vector
y<-c(2,4,6,8,10)

##Now we can manipulate the vectors using basic arithmetic
x+4
y-3
z<-x+y
z 

##Vectors can be combined to make a matrix
data<-cbind(x,y)
data 

##Basic statistical functions are built in
mean(x)
median(x)
var(x)
sd(x)
summary(x)
summary(data)

##There's more than one type of data
grade<-c("a","b","c","d","a")#R will recognize this as a character vector
summary(grade)##Unfortunately, there's not much we can do with a character vector 

##Changing the data type
grade.f<-as.factor(grade)
summary(grade.f)##This factor is much more useful
class(grade.f)##Note that the summary didn't tell us the class
length(grade.f)

##We can still combine different types of data to make a dataframe, but not a matrix
data<-data.frame(x,y,grade.f)#Note that this will overwrite the previous data
#If you ask Stata to generate a variable that already exists, you get an error
#That doesn't happen in R. It just overwrites it. 

##loading data sets with years can sometimes create a problem
year<-c(2010,2011,2012,2013,2014)
summary(year)#The mean year is 2012
year<-as.factor(year)
summary(year)

##R can handle more than one dataframe at a time
data2<-data.frame(year,grade.f,y)
  
##This makes it much easier to merge data frames. 
merged.data<-merge(data,data2,by=c("grade.f","y"))
#In this case either variable would be sufficient by itself

##Cleaning up
ls()##list everying
rm(y)##remove y
rm(list=ls())##remove everything

#####################
##Using Actual Data##
#####################

#For this workshop, I'm using data on county-level health indicators
#Data is from the Robert Wood Johnson Foundation, 2015
#You can get it online here: http://www.countyhealthrankings.org/rankings/data

#First we need to get it ready to read into R
#I've saved the separate excel sheets as CSVs
#Now I'm going to read in the first one

Health.Outcomes.Rankings<-read.csv(file.choose(),header=TRUE,skip=1)
##I skipped the top line of the CSV, and then had R use the second line as the header
summary(Health.Outcomes.Rankings)
##The problem is these names aren't very helpful
fix(Health.Outcomes.Rankings)##Opens an interactive data editor
names(Health.Outcomes.Rankings)

#Usually though, it's easier to rename them in the CSV before reading them in
#That way you don't have to remember which one 1 and so forth. 

##So for this one I've done that and the renamed version is with your workshop materials
Subrankings<-read.csv(file.choose(),header=TRUE,skip=1)
summary(Subrankings)##Why does KY have so many counties??

##Now I want to merge my two datasets together
healthdata<-merge(Health.Outcomes.Rankings,Subrankings, by=c("State","County", "FIPS"))
#In this case state and county or FIPS would have been enough
#I used all three because otherwise you get extra variables like FIPS.1

#subsetting
healthdata.ky<-subset(healthdata, State == "Kentucky")#Note the double == is necessary
#This concludes Kentucky overall, a quirk of the RWJF data
#So instead,
healthdata.ky<-subset(healthdata, State == "Kentucky" & County !="")

#Correlation test
names(healthdata.ky)#because sometimes you forget exactly what they're called
cor.test(healthdata.ky$Outcomes.Z,healthdata.ky$Factors.Z)

#######
##OLS##
#######

model1<-lm(Outcomes.Z~Health.Behaviors.Z+Clinical.Care.Z+Social.Economic.Z+
             Physical.Environment.Z, data=healthdata.ky)
summary(model1)

#all data, not just kentucky
model2<-lm(Outcomes.Z~Health.Behaviors.Z+Clinical.Care.Z+Social.Economic.Z+
             Physical.Environment.Z, data=healthdata)
summary(model2)

##Exploring the Regression Results
?lm##asking for help
summary(model1$residuals)
summary(residuals(model1))#this does the same thing

fitted(model1)
model1$coefficients
model1$fitted.values

##you can also get diagnostic plots easily
plot(model1)
#and an anova table
anova(model1)

##Robust standard Errors
#This is slightly more involved than Stata
#The easiest way involves downloading an additional code package:
require("sandwich")#This will install it if it's not installed already

#Now we can develop new standard errors
model1$newse<-vcovHC(model1,type="HC1")#Heteroskedasticity Consistent 1 is Stata's default
model1.display<-coeftest(model1,model1$newse)#applying the robust SEs to the model 
round(model1.display, digits=3)

##################
##Extra Material##
##################

#Graphing

#Mosaic Plot
#First I'm making a dataframe of just the variables I want to graph
keepvars<-c("Outcomes.Z","Health.Behaviors.Z","Clinical.Care.Z", "Social.Economic.Z", "Physical.Environment.Z")
plot.data<-healthdata[keepvars]
plot(plot.data)
plot.data.ky<-healthdata.ky[keepvars]
plot(plot.data.ky)

##ggplot2 allows you to build plots in layers
require(ggplot2)
plot1<-ggplot(aes(x=Social.Economic.Z, y=Outcomes.Z),
              data=healthdata.ky)+geom_point()
plot1
plot1<-plot1+geom_smooth(method="lm", colour="red")+
  labs(x="SES", y="Health Outcomes", title="SES and Health in KY, 2015")
plot1

#Can also color code by factors
healthdata.ky.tn<-subset(healthdata, State == "Kentucky" | State == "Tennessee")
plot2<-ggplot(aes(x=Social.Economic.Z, y=Outcomes.Z, colour=factor(healthdata.ky.tn$State)),
              data=healthdata.ky.tn)+geom_point()
plot2+geom_smooth(aes(group=1),method="lm")+
  labs(x="SES", y="Health Outcomes", title="SES and Health in KY and TN, 2015",
       colour="State")



#aggregating data by state

#First we need some non-Z-score data
county.data<-read.csv(file.choose(),header=T)
summary(county.data)

#Now we can aggregate
mean.obese<-aggregate(county.data$Percent.Obese, list(county.data$State), mean)
mean.obese
max.obese<-aggregate(county.data$Percent.Obese, list(county.data$State), max)
max.obese
state.data<-merge(mean.obese,max.obese, by="Group.1")#combining the data
state.data<-state.data[order(state.data$x.x, decreasing=TRUE),]#reordering it

#recoding variables
healthdata.ky$SES<-NA
healthdata.ky$SES[healthdata.ky$Social.Economic.Z>=0.25]<-"High"
healthdata.ky$SES[healthdata.ky$Social.Economic.Z< 0.25& healthdata.ky$Social.Economic.Z > -0.25]<-"Medium"
healthdata.ky$SES[healthdata.ky$Social.Economic.Z<=-0.25]<-"Low"

#We can use this new variable in plots
plot3<-ggplot(aes(x=Clinical.Care.Z, y=Outcomes.Z, colour=factor(healthdata.ky$SES)),
              data=healthdata.ky)+geom_point()
plot3+geom_smooth(aes(group=1),method="lm")+
  labs(x="Clinical Care", y="Health Outcomes", 
       title="Clinical Care and Health by SES in KY, 2015", colour="SES")

#functions
county.data.ky<-subset(county.data, State == "Kentucky")

NormZ<-function(x){
  (x-mean(x))/sd(x)
}
county.data.ky$Obese.Z<-NormZ(county.data.ky$Percent.Obese)

##useful resources
#Quick-R: http://www.statmethods.net/
#R-bloggers:http://www.r-bloggers.com/
#Google - this will often take you to stackoverflow
